userFlaviencancel
reporust_rebootcancel

8,326 Commits over 1,035 Days - 0.34cph!

5 Days Ago
Fixed store NEW notification when skins are released
5 Days Ago
Reduced the range of 62 lights in the caboose from 80 to 15 meters (they have a 1m range) Saves aroud 0.1ms when close to outpost with the caboose switched on S2P outpost
5 Days Ago
merge from piemenu_icons_stacked_fix
5 Days Ago
Fix attempt for pie menu icons stacked top right and emojis offset
5 Days Ago
Fixed limited store grid NRE
5 Days Ago
merge from store_gridnre_fix
6 Days Ago
Deleted 25 rocks placed 2.5km under the terrain in the excavator monument S2P excavator
6 Days Ago
Restored codegen
6 Days Ago
Preload 324 cow and sheep sounds like the other animals Avoids a ~1.2ms hitch the first time each clip plays, memory impact is only around 3MB
6 Days Ago
▇▅▅▊▋▇ ▉▉▇▌ ▊▆▇▊▅▍▉▆▉▄▋▇▆▆▉▊▊▄▇▅▇▋▉▍█▉
6 Days Ago
▌▌██▇█ ▄ ▄▆▉▍ █▊▅█ ▆▅▊▉ ▊▊▅▄▌█ ▄▌▇▄▇▍ █▅▍▅▉ ▇▌▊ ▋▍▍█▄▇█▍▌▉
6 Days Ago
merge from more_lod_optims
6 Days Ago
Use a hashset for the combined mesh lookup from 169597, Contains was slow on big ass bases
6 Days Ago
Fixed LODs showing their level a second time after being enabled, was tooking batched blocks out of their batch and back in for nothing
6 Days Ago
Fixed opening a double door rebuilding the batched walls around it, the door frame now stays batched while the door swings Regression from 169567
6 Days Ago
merge from more_lod_optims
6 Days Ago
Fixed pooled blocks staying unbatched, their LOD component asked to batch them before their RendererBatch component was enabled
6 Days Ago
Gamepad icon for the gamepad section in the settings
7 Days Ago
Batched meshes only recalculate UV0 distribution metric, UV1 are for lightmaps which we don't use Editor profiling, walking around the same big base: RendererCell.ApplyBatches ~4.5ms -> ~3.1ms
7 Days Ago
Optimised RendererGroup invalidation, only the combined mesh holding the block is switched back to separate renderers Editor profiling, walking around the same big base: slowest LOD switch ~2.5ms -> ~1ms
7 Days Ago
Fixed batch groups staying unbatched for good when their rebuild got cancelled by another change in the same cell
7 Days Ago
Fixed LODs being worked out from the camera position before a respawn or CCTV switch (regression from 169523)
7 Days Ago
Bunch of LOD optims: - The budget is now checked mid cell, if a dense cell exceeds the budget we pause and resume on the next frame. Fixes big spikes for large cells - Camera and player positions are read once per frame instead of by every LOD member - Static LOD members cache their grid position - Mesh and renderer LODs skip their update while their distance stays between the same LOD distances Editor profiling, walking around a big base, LODGrid p99 frame: ~15ms -> ~1ms (max budget)
8 Days Ago
merge from cui_blur_fix2
8 Days Ago
Fixed allocations in SortBlurredLayers
8 Days Ago
Raised the UI blur capture limit from 4 to 6 per frame CUI blurs only take a capture of their own when they cover UI drawn before them CUI blur sorting runs once per frame instead of on every AddUI/DestroyUI
8 Days Ago
merge from socialmenu_perf_fixs
8 Days Ago
Virtualised the friend sections so we don't have a ton of prefab instantiated Changed the friends name sort to ordinal ignore case 1000 friends rebuild, menu opened: ~159ms -> ~14ms
8 Days Ago
Throttle friends list rebuilds from status changes to once every 2s while the friends menu is open, instead of every 0.2s
8 Days Ago
Discord presence changes no longer rebuild the list while the friends menu is closed
8 Days Ago
merge from ladderhatch_close_fix
8 Days Ago
Fixed being unable to close open ladder hatches from certain angles
8 Days Ago
merge from cui_blur_fix2
8 Days Ago
Fixed CUI blur stacking sorting issues
9 Days Ago
Moved MenuUI2's UIBlurCanvasesBehind from FadedBackground to PageBackground as it needs a CanvasRenderer
9 Days Ago
merge from uiblur_faded_fix
9 Days Ago
▋▋▄▊█▄ ▌▇▅▉ ▇▇▅▋▄▅▍▉█▇▄▇▇▅▅▍▆▉█▊▊▊▉▄▍▍▇▋▍▋▆▇▍
9 Days Ago
merge from static-cctv_fix
9 Days Ago
merge from uiblur_faded_fix
9 Days Ago
Cleanup
9 Days Ago
UIBlurCanvasesBehind skips the capture while a CanvasGroup above is faded out
9 Days Ago
▌▋▊▅▄▉▆ ▍▅▅▋▅▆▇█ ▄▆▇▉▍▅▌█▄ ▋▋ ▌█▆▅ ▆▅▌▉▌▉▋▅▉▍ ▍▋▅▄▇▄▇▋▌ ▅▍█▇▍▌▍ ▇▊▇ ▇ ▋▋▋▄▍ ▉▇▊█▍▆▄▌▉ ▄▇▋█▊▊▇▄▉▄▅▌
9 Days Ago
Fixed io infinite power convar breaking static cctv cameras
9 Days Ago
▆▍▉▉▊▍▌█ ▋▄▉▌▆▋ ▇▅▄▉█▌▋ ▅▍▍ █▌▆ ▉▇▊ ▅▇▊▉▋▇▆▅▄▆▊
9 Days Ago
▊▄▅▆▋▌ ▆▋▄▄ ▉▊▍▇▌▌▄▊▍▄▄▌▍▋▅▋▉▋▅▅▄▇█
9 Days Ago
▉▉▄█▄▊ ▊▋▇▄▊▋▆▇▊▄ ▋▅▊▆▍▉▅▋ ▊▅▄▆█ ▅▄▆▍▍▉ ▆█▄▍▆ ▇▋▌▋█▆▇█▌▄▆▉▊ ▊▄▄█▇ ▋▍▊ █▆▅▄█▋▇ ▌▇▉▊ ▅█▌▆▋▇▆▇▋▉▇▇▍ ▉▉▇▍▉▌▅ ▆▄ ▉▍█▊▋▄█▄▊█ █▉▇▆▋▌▆▄ ▄▇▅▅▅▍ ▆█▌█ ▇▇▉▇█ ▅▍▍▋ ▅▊▆ ▌▋ ▌▍▌█▆ ▇▉▅▆
9 Days Ago
▍▄▉▇▋▇ █▆▋▆ ▍▌▌▋
9 Days Ago
merge from bagmarkers_fix
9 Days Ago
merge from adminui_ugc_scrollbarfix
9 Days Ago
merge from ramp_deploy_fix